//=========================================================
//  MusE
//  Linux Music Editor
//  $Id: font.h,v 1.1.1.1 2003/10/29 10:05:08 wschweer Exp $
//
//  (C) Copyright 1999/2000 Werner Schweer (ws@seh.de)
//=========================================================

#ifndef __FONT_H__
#define __FONT_H__

#include <qfont.h>

//---------------------------------------------------------
//   Font
//---------------------------------------------------------

class Font : public QFont {
   public:
      Font() : QFont(QString("Carter")) { }
      Font(const QFont& f) : QFont(f) {}
      Font(const QString& f, int pointSize=12, int weight = Normal,
        bool italic = false) : QFont(f, pointSize, weight, italic) {}
      };

#endif

